@@ -72,6 +72,17 @@ class RecipeEntryPoint(DAG):
         extensions=['wea']
     )
 
+    dmtx_group_params = Inputs.str(
+        description='A string to change the parameters for aperture grouping for '
+        'daylight matrix calculation. Valid keys are -s for aperture grid size, -t for '
+        'the threshold that determines if two apertures/aperture groups can be '
+        'clustered, and -ad for ambient divisions used in view factor calculation '
+        'The default is -s 0.2 -t 0.001 -ad 1000. The order of the keys is not '
+        'important and you can include one or all of them. For instance if you only '
+        'want to change the aperture grid size to 0.5 you should use -s 0.5 as the '
+        'input.', default='-s 0.2 -t 0.001 -ad 1000'
+    )
+
     @task(template=CreateRadianceFolderGrid)
     def create_rad_folder(self, input_model=model, grid_filter=grid_filter):
         """Translate the input model to a radiance folder."""
@@ -244,7 +255,8 @@ class RecipeEntryPoint(DAG):
         model_folder=create_rad_folder._outputs.model_folder,
         octree=create_octrees._outputs.scene_folder,
         sky_dome=create_sky_dome._outputs.sky_dome,
-        bsdf_folder=create_rad_folder._outputs.bsdf_folder
+        bsdf_folder=create_rad_folder._outputs.bsdf_folder,
+        dmtx_group_params=dmtx_group_params
     ):
         return [
             {
@@ -288,7 +300,6 @@ class RecipeEntryPoint(DAG):
         sky_dome=create_sky_dome._outputs.sky_dome,
         sky_matrix=create_total_sky._outputs.sky_matrix,
         bsdf_folder=create_rad_folder._outputs.bsdf_folder,
-        multiplication_options='-h'
     ):
         return [
             {
